@@ -17,13 +17,13 @@
  * 
  * </EN>
  * 
- * $Revision: 1.6 $
+ * $Revision: 1.11 $
  * 
  */
 /*
  * Copyright (c) 1991-2006 Kawahara Lab., Kyoto University
  * Copyright (c) 2000-2005 Shikano Lab., Nara Institute of Science and Technology
- * Copyright (c) 2005-2006 Julius project team, Nagoya Institute of Technology, Nagoya Institute of Technology
+ * Copyright (c) 2005-2006 Julius project team, Nagoya Institute of Technology
  * All rights reserved
  */
 
@@ -92,7 +92,7 @@ GLOBAL char *gmm_filename GLOBAL_VAL(NULL); ///< GMM definition file
 GLOBAL int speech_input GLOBAL_VAL(SP_MFCFILE); ///< Selected input source
 GLOBAL int adinnet_port GLOBAL_VAL(ADINNET_PORT); ///< Port number for adinnet input
 #ifdef USE_NETAUDIO
-GLOBAL char *netaudio_devname GLOBAL_VAL("localhost:0"); ///< Host/unit name for NetAudio/DatLink input
+GLOBAL char *netaudio_devname GLOBAL_VAL(NULL); ///< Host/unit name for NetAudio/DatLink input
 #endif
 
 /********************************************/
@@ -108,29 +108,17 @@ GLOBAL boolean use_zmean GLOBAL_VAL(FALSE); ///< If TRUE, remove DC offset by ze
 
 /********************************************/
 /* Speech analysis parameters */
-GLOBAL int smpPeriod GLOBAL_VAL(625); ///< Sampling period (16kHz: 625ns)
-GLOBAL int smpFreq GLOBAL_VAL(16000); ///< Sampling freq.  (16kHz: 625ns)
-GLOBAL int fshift GLOBAL_VAL(DEF_FRAMESHIFT); ///< Frame shift (160sample = 10ms in 16kHz)
-GLOBAL int fsize GLOBAL_VAL(DEF_FRAMESIZE); ///< Window size (400sample = 25ms in 16kHz)
-GLOBAL int delwin GLOBAL_VAL(DEF_DELWIN); ///< Default delta window length
-GLOBAL int accwin GLOBAL_VAL(DEF_ACCWIN); ///< Default accel window length
-/* Lo-pass/hi-pass filter */
-GLOBAL int hipass GLOBAL_VAL(-1); ///< Frequency of hi pass filter, or -1 to disable
-GLOBAL int lopass GLOBAL_VAL(-1); ///< Frequency of lo pass filter, or -1 to disable
-GLOBAL float preemph GLOBAL_VAL(DEF_PREENPH); ///< Pre-emphasis coefficient
-GLOBAL int fbank_num GLOBAL_VAL(DEF_FBANK); ///< Number of filterbank channels
-GLOBAL int ceplifter GLOBAL_VAL(DEF_CEPLIF); ///< Cepstral liftering coefficient
-GLOBAL boolean rawe_required GLOBAL_VAL(FALSE); ///< If TRUE, use raw energy before emphasis
-GLOBAL boolean enormal_required GLOBAL_VAL(FALSE); ///< If TRUE normalize log energy.  Always FALSE for live input
-GLOBAL float enormal_escale GLOBAL_VAL(1.0); ///< Scale log energy when normalizing
-GLOBAL float enormal_silfloor GLOBAL_VAL(DEF_SILFLOOR); ///< Energy silence floor in Db when normalizing
+GLOBAL Value para;		///< MFCC computation parameters
+GLOBAL Value para_hmm;		///< MFCC computation parameters from HMM header
+GLOBAL Value para_htk;	///< MFCC parameters read from HTK Config
+GLOBAL Value para_default;    ///< default MFCC computation parameters
+GLOBAL Value para_dummy;    ///< dummy entry for reading binary GMM/GMS HMMs
 
 /********************************************/
 /* Spectral subtraction */
 GLOBAL boolean sscalc GLOBAL_VAL(FALSE); ///< If TRUE, compute SS using head silence for file input
 GLOBAL int sscalc_len GLOBAL_VAL(300); ///< Length of speech at input head to compute SS in msec
-GLOBAL float ssalpha GLOBAL_VAL(DEF_SSALPHA); ///< Alpha coef. for SS
-GLOBAL float ssfloor GLOBAL_VAL(DEF_SSFLOOR); ///< Spectral floor for SS
+/* ssfloor, ssalpha moved into Value */
 
 /********************************************/
 /* LM parameters (default will be set in m_bootup.c) */
@@ -168,13 +156,13 @@ GLOBAL LOGPROB cm_cut_thres_pop GLOBAL_VAL(0.1); ///< Cut-off threshold for popp
 /********************************************/
 /* Pause (silence) model related */
 #ifdef USE_NGRAM
-GLOBAL char *head_silname GLOBAL_VAL(BEGIN_WORD_DEFAULT); ///< Silence model name at beginning of search
-GLOBAL char *tail_silname GLOBAL_VAL(END_WORD_DEFAULT); ///< Silence model name at end of search
+GLOBAL char *head_silname GLOBAL_VAL(NULL); ///< Silence model name at beginning of search
+GLOBAL char *tail_silname GLOBAL_VAL(NULL); ///< Silence model name at end of search
 /* Short pause word, that will be added to dictionary when "-iwspword" is spcified */
 GLOBAL boolean enable_iwspword GLOBAL_VAL(FALSE); ///< Enable addition of short pause word to dictionary
-GLOBAL char *iwspentry GLOBAL_VAL(IWSPENTRY_DEFAULT); ///< Dictionary entry to be added as short-pause word
+GLOBAL char *iwspentry GLOBAL_VAL(NULL); ///< Dictionary entry to be added as short-pause word
 #endif
-GLOBAL char *spmodel_name GLOBAL_VAL(SPMODEL_NAME_DEFAULT); ///< Logical HMM name of short pause model
+GLOBAL char *spmodel_name GLOBAL_VAL(NULL); ///< Logical HMM name of short pause model
 
 #ifdef MULTIPATH_VERSION
 /* 1) in DFA mode, a word with only "spmodel_name" model as a pronunciation will be specially handled as "short-pause word" */
@@ -314,7 +302,7 @@ GLOBAL boolean module_mode GLOBAL_VAL(FALSE);///< TRUE if started as module
 /* Output switches */
 GLOBAL boolean verbose_flag GLOBAL_VAL(TRUE); ///< Verbose output
 GLOBAL boolean debug2_flag GLOBAL_VAL(FALSE); ///< Debug output
-GLOBAL boolean paramtype_check_flag GLOBAL_VAL(TRUE); ///< if TRUE, check MFCC parameter type with header of the hmmdefs
+GLOBAL boolean paramtype_check_flag GLOBAL_VAL(TRUE); ///< if TRUE, check input parameter type with header of the hmmdefs
 GLOBAL boolean progout_flag GLOBAL_VAL(FALSE); ///< Progressive output
 #ifdef USE_NGRAM
 GLOBAL boolean separate_score_flag GLOBAL_VAL(FALSE); ///< Output both AM and LM score separately
@@ -335,9 +323,6 @@ GLOBAL boolean realtime_flag GLOBAL_VAL(FALSE);	///< Do on-the-fly decoding if T
 GLOBAL boolean ccd_flag GLOBAL_VAL(TRUE); ///< Handle hmmdefs as context-dependent HMM if TRUE (default determined from hmmdefs macro name)
 GLOBAL boolean ccd_flag_force GLOBAL_VAL(FALSE); ///< If TRUE, user-specified ccd_flag will override hmmdefs defaults
 
-/* Misc */
-GLOBAL boolean catch_intr_flag GLOBAL_VAL(FALSE); ///< TRUE when should catch SIGINT
-
 /* -------------------------------------------------------------- */
 /* -------- Work area for search -------------------------------- */
 /* -------------------------------------------------------------- */
@@ -371,14 +356,6 @@ GLOBAL LOGPROB *framemaxscore;///< Maximum score of each frame on 2nd pass
 GLOBAL SP16 speech[MAXSPEECHLEN]; ///< Input speech data
 GLOBAL int speechlen GLOBAL_VAL(0);		///< Length of @a speech
 GLOBAL boolean cmn_loaded GLOBAL_VAL(FALSE); ///< TRUE if CMN parameter loaded from file at boot up
-GLOBAL boolean delta_required GLOBAL_VAL(TRUE); ///< TRUE if delta coeff. required
-GLOBAL boolean acc_required GLOBAL_VAL(FALSE); ///< TRUE if acceleration coeff. required
-GLOBAL boolean energy_required GLOBAL_VAL(TRUE); ///< TRUE if energy coeff. required
-GLOBAL boolean abs_energy_suppress GLOBAL_VAL(TRUE); ///< TRUE if absolute energy should be suppressed
-GLOBAL boolean c0_required GLOBAL_VAL(FALSE); ///< TRUE when 0'th Cepstral parameter is used instead of energy in hmmdefs
-GLOBAL boolean cmn_required GLOBAL_VAL(TRUE); ///< TRUE if hmmdefs requires CMN
-GLOBAL int model_mfcc_dim GLOBAL_VAL(12); ///< base MFCC dim specified by HMM
-GLOBAL boolean zmean_frame GLOBAL_VAL(FALSE); ///< If TRUE, perform frame-wise zmean source for wave input like HTK
 
 /* Spectral subtraction */
 GLOBAL float *ssbuf GLOBAL_VAL(NULL);///< Estimated noise spectrum
