@@ -34,13 +34,13 @@
  * i.e. the score order of the previous frame is not used here.
  * </EN>
  * 
- * $Revision: 1.3 $
+ * $Revision: 1.5 $
  * 
  */
 
 /*
  * Copyright (c) 2003-2005 Shikano Lab., Nara Institute of Science and Technology
- * Copyright (c) 2005-2006 Julius project team, Nagoya Institute of Technology, Nagoya Institute of Technology
+ * Copyright (c) 2005-2006 Julius project team, Nagoya Institute of Technology
  * All rights reserved
  */
 
@@ -187,9 +187,9 @@ gmm_compute_g_base(HTK_HMM_Dens *binfo)
   tmp = 0.0;
   for (; veclen > 0; veclen--) {
     x = *(vec++) - *(mean++);
-    tmp += x * x / *(var++);
+    tmp += x * x * *(var++);
   }
-  return((tmp + binfo->gconst) / -2.0);
+  return((tmp + binfo->gconst) * -0.5);
 }
 
 /** 
@@ -228,10 +228,10 @@ gmm_compute_g_safe(HTK_HMM_Dens *binfo, LOGPROB thres)
   tmp = binfo->gconst;
   for (; veclen > 0; veclen--) {
     x = *(vec++) - *(mean++);
-    tmp += x * x / *(var++);
+    tmp += x * x * *(var++);
     if (tmp > fthres)  return LOG_ZERO;
   }
-  return(tmp / -2.0);
+  return(tmp * -0.5);
 }
 
 /** 
@@ -340,7 +340,7 @@ gmm_calc_mix(HTK_HMM_State *s)
   }
   logprob = addlog_array(OP_calced_score, OP_calced_num);
   if (logprob <= LOG_ZERO) return LOG_ZERO;
-  return (logprob / LOG_TEN);
+  return (logprob * INV_LOG_TEN);
 }
 
 /** 
@@ -417,6 +417,14 @@ gmm_init(HTK_HMM_INFO *gmm, int gmm_prune_num)
 
   /* initialize work area */
   gmm_gprune_safe_init(gmm, gmm_prune_num);
+
+  /* check if variances are inversed */
+  if (!gmm->variance_inversed) {
+    /* here, inverse all variance values for faster computation */
+    htk_hmm_inverse_variances(gmm);
+    gmm->variance_inversed = TRUE;
+  }
+
 }
 
 /** 
