@@ -11,14 +11,14 @@
  * @brief  Main function of Julius/Julian
  * </EN>
  * 
- * $Revision: 1.3 $
+ * $Revision: 1.8 $
  * 
  */
 /*
  * Copyright (c) 1991-2006 Kawahara Lab., Kyoto University
  * Copyright (c) 1997-2000 Information-technology Promotion Agency, Japan
  * Copyright (c) 2000-2005 Shikano Lab., Nara Institute of Science and Technology
- * Copyright (c) 2005-2006 Julius project team, Nagoya Institute of Technology, Nagoya Institute of Technology
+ * Copyright (c) 2005-2006 Julius project team, Nagoya Institute of Technology
  * All rights reserved
  */
 
@@ -263,12 +263,12 @@ main_recognition_loop()
   /***************************/
   /* Model/IO initialization */
   /***************************/
-  /* initialize and standby audio input device */
-  adin_initialize();
-  
   /* initialize all models, work area, parameters to bootup system */
   final_fusion();
 
+  /* initialize and standby audio input device */
+  adin_initialize();
+  
   /* print out system information */
   print_info();
 
@@ -295,9 +295,9 @@ main_recognition_loop()
     /* open input stream */
     /*********************/
     if (speech_input == SP_MFCFILE) {
-      /*******************************************/
-      /* read pre-analyzed parameter file (MFCC) */
-      /*******************************************/
+      /************************************/
+      /* read pre-analyzed parameter file */
+      /************************************/
       VERMES("### read analyzed parameter\n");
       /* from MFCC parameter file (in HTK format) */
       if (inputlist_filename != NULL) {	/* has filename list */
@@ -317,7 +317,7 @@ main_recognition_loop()
       /* read parameter file */
       param = new_param();
       if (rdparam(speechfilename, param) == FALSE) {
-	j_printerr("error in reading MFCC file: %s\n",speechfilename);
+	j_printerr("error in reading parameter file: %s\n",speechfilename);
 	free(speechfilename);
 	free_param(param);
 	continue;
@@ -577,7 +577,7 @@ main_recognition_loop()
 	  status_recend();
 
 	  /* output recorded length */
-	  seclen = (float)speechlen / (float)smpFreq;
+	  seclen = (float)speechlen / (float)para.smp_freq;
 	  j_printf("%d samples (%.2f sec.)\n", speechlen, seclen);
 
 	  /* -rejectshort , ϤְʲǤ
@@ -597,7 +597,10 @@ main_recognition_loop()
 	  VERMES("### speech analysis (waveform -> MFCC)\n");
 	  /* CMN will be computed for the whole buffered input */
 	  param = new_wav2mfcc(speech, speechlen);
-	  if (param == NULL) goto end_recog;
+	  if (param == NULL) {
+	    ret = -1;
+	    goto end_recog;
+	  }
 
 	  /* if terminate signal has been received, cancel this input */
 	  if (module_mode && module_wants_terminate()) goto end_recog;
@@ -659,7 +662,7 @@ main_recognition_loop()
       /* when using "-rejectshort", and input was shorter than the specified
 	 length, terminate search here and output recognition failure */
       if (rejectshortlen > 0) {
-	mseclen = (float)param->samplenum * (float)smpPeriod * (float)fshift / 10000.0;
+	mseclen = (float)param->samplenum * (float)para.smp_period * (float)para.frameshift / 10000.0;
 	if (mseclen < rejectshortlen) {
 	  result_rejected("too short input");
 	  goto end_recog;
@@ -675,6 +678,7 @@ main_recognition_loop()
       if (backmax == LOG_ZERO) {
 	/* j_printerr("Terminate 2nd pass.\n"); */
 	result_pass2_failed(wchmm->winfo);
+	ret = -1;
 	goto end_recog;
       }
 
@@ -846,5 +850,8 @@ main(int argc, char *argv[])
     main_recognition_loop();
   }
 
+  /* release global variables allocated when parsing options */
+  opt_release();
+
   return 0;
 }
