@@ -11,13 +11,13 @@
  * @brief  Output recoginition result via module socket.
  * </EN>
  * 
- * $Revision: 1.3 $
+ * $Revision: 1.5 $
  * 
  */
 /*
  * Copyright (c) 1991-2006 Kawahara Lab., Kyoto University
  * Copyright (c) 2000-2005 Shikano Lab., Nara Institute of Science and Technology
- * Copyright (c) 2005-2006 Julius project team, Nagoya Institute of Technology, Nagoya Institute of Technology
+ * Copyright (c) 2005-2006 Julius project team, Nagoya Institute of Technology
  * All rights reserved
  */
 
@@ -566,7 +566,7 @@ msock_status_recend()
 void
 msock_status_param(HTK_Param *param)
 {
-  module_send(module_sd, "<INPUTPARAM FRAMES=\"%d\" MSEC=\"%d\"/>\n.\n", param->samplenum, param->samplenum * (int)((float)smpPeriod * (float)fshift / 10000.0));
+  module_send(module_sd, "<INPUTPARAM FRAMES=\"%d\" MSEC=\"%d\"/>\n.\n", param->samplenum, param->samplenum * (int)((float)para.smp_period * (float)para.frameshift / 10000.0));
 }
 
 /**********************************************************************/
