@@ -15,13 +15,13 @@
  * Ƥޤ
  * </JA>
  *
- * $Revision: 1.3 $
+ * $Revision: 1.6 $
  * 
  */
 /*
  * Copyright (c) 1991-2006 Kawahara Lab., Kyoto University
  * Copyright (c) 2000-2005 Shikano Lab., Nara Institute of Science and Technology
- * Copyright (c) 2005-2006 Julius project team, Nagoya Institute of Technology, Nagoya Institute of Technology
+ * Copyright (c) 2005-2006 Julius project team, Nagoya Institute of Technology
  * All rights reserved
  */
 
@@ -31,6 +31,7 @@
 #include <sent/stddefs.h>
 #include <sent/htk_defs.h>
 #include <sent/ptree.h>
+#include <sent/mfcc.h>
 
 /// Macro to check whether the next token is "A"
 #define currentis(A)  (!strcasecmp(A, rdhmmdef_token))
@@ -362,6 +363,7 @@ typedef struct {
 #ifdef MULTIPATH_VERSION
   LOGPROB iwsp_penalty;		///< Extra ransition penalty for interword skippable short pause insertion
 #endif
+  boolean variance_inversed;	///< TRUE if variances are inversed
   
   int totalmixnum;		///< Total number of defined mixtures
   int totalstatenum;		///< Total number of states
@@ -387,6 +389,7 @@ void htk_hmm_set_pause_model(HTK_HMM_INFO *hmminfo, char *spmodel_name);
 void rderr(char *str);
 char *read_token(FILE *fp);
 boolean rdhmmdef(FILE *, HTK_HMM_INFO *);
+void htk_hmm_inverse_variances(HTK_HMM_INFO *hmm);
 /* rdhmmdef_options.c */
 void set_global_opt(FILE *fp, HTK_HMM_INFO *hmm);
 char *get_cov_str(short covtype);
@@ -430,7 +433,7 @@ void put_logical_hmm(HMM_Logical *l);
 void print_hmmdef_info(HTK_HMM_INFO *);
 HTK_HMM_INFO *hmminfo_new();
 boolean hmminfo_free(HTK_HMM_INFO *);
-void init_hmminfo(HTK_HMM_INFO *hmminfo, char *filename, char *mapfile);
+void init_hmminfo(HTK_HMM_INFO *hmminfo, char *filename, char *mapfile, Value *para);
 HTK_HMM_Data *htk_hmmdata_lookup_physical(HTK_HMM_INFO *, char *);
 HMM_Logical *htk_hmmdata_lookup_logical(HTK_HMM_INFO *, char *);
 void hmm_add_physical_to_logical(HTK_HMM_INFO *);
@@ -474,7 +477,7 @@ HTK_Param *new_param_check_and_adjust(HTK_HMM_INFO *hmm, HTK_Param *pinfo, boole
 
 
 /* binary format */
-boolean write_binhmm(FILE *fp, HTK_HMM_INFO *hmm);
-boolean read_binhmm(FILE *fp, HTK_HMM_INFO *hmm, boolean gzfile_p);
+boolean write_binhmm(FILE *fp, HTK_HMM_INFO *hmm, Value *para);
+boolean read_binhmm(FILE *fp, HTK_HMM_INFO *hmm, boolean gzfile_p, Value *para);
 
 #endif /* __SENT_HTK_HMM_2_H__ */
