@@ -11,13 +11,13 @@
  * @brief  Load %HMM definition file and HMMList mapping file into memory and set it up.
  * </EN>
  * 
- * $Revision: 1.4 $
+ * $Revision: 1.8 $
  * 
  */
 /*
  * Copyright (c) 1991-2006 Kawahara Lab., Kyoto University
  * Copyright (c) 2000-2005 Shikano Lab., Nara Institute of Science and Technology
- * Copyright (c) 2005-2006 Julius project team, Nagoya Institute of Technology, Nagoya Institute of Technology
+ * Copyright (c) 2005-2006 Julius project team, Nagoya Institute of Technology
  * All rights reserved
  */
 
@@ -70,6 +70,7 @@ hmminfo_new()
   new->sp = NULL;
   new->basephone.root = NULL;
   new->cdset_info.cdtree = NULL;
+  new->variance_inversed = FALSE;
 
   return(new);
 }
@@ -115,9 +116,10 @@ hmminfo_free(HTK_HMM_INFO *hmm)
  * @param hmminfo [out] pointer to store all the %HMM definition data.
  * @param hmmfilename [in] file name of HTK %HMM definition file, NULL if not.
  * @param namemapfile [in] file name of HMMList mapping file.
+ * @param para [out] store acoustic analysis condition parameters if exist in hmmfilename.
  */
 void
-init_hmminfo(HTK_HMM_INFO *hmminfo, char *hmmfilename, char *namemapfile)
+init_hmminfo(HTK_HMM_INFO *hmminfo, char *hmmfilename, char *namemapfile, Value *para)
 {
   FILE *fp;
   boolean ok_p;
@@ -141,7 +143,7 @@ init_hmminfo(HTK_HMM_INFO *hmminfo, char *hmmfilename, char *namemapfile)
     if ((fp = fopen_readfile(hmmfilename)) == NULL) {
       j_error("failed to open %s\n",hmmfilename);
     }
-    if (read_binhmm(fp, hmminfo, TRUE) == TRUE) {
+    if (read_binhmm(fp, hmminfo, TRUE, para) == TRUE) {
       ok_p = TRUE;
     }
     if (fclose_readfile(fp) < 0) {
