@@ -29,13 +29,13 @@
  * calc_tied_mix() or calc_mix().
  * </EN>
  * 
- * $Revision: 1.4 $
+ * $Revision: 1.7 $
  * 
  */
 /*
  * Copyright (c) 1991-2006 Kawahara Lab., Kyoto University
  * Copyright (c) 2000-2005 Shikano Lab., Nara Institute of Science and Technology
- * Copyright (c) 2005-2006 Julius project team, Nagoya Institute of Technology, Nagoya Institute of Technology
+ * Copyright (c) 2005-2006 Julius project team, Nagoya Institute of Technology
  * All rights reserved
  */
 
@@ -66,12 +66,12 @@ compute_g_base(HTK_HMM_Dens *binfo)
   if (binfo == NULL) return(LOG_ZERO);
   mean = binfo->mean;
   var = binfo->var->vec;
-  tmp = 0.0;
+  tmp = binfo->gconst;
   for (; veclen > 0; veclen--) {
     x = *(vec++) - *(mean++);
-    tmp += x * x / *(var++);
+    tmp += x * x * *(var++);
   }
-  return((tmp + binfo->gconst) / -2.0);
+  return(tmp * -0.5);
 }
 
 /** 
