@@ -33,13 +33,13 @@
  *      -# use outprob(t, hmmstate, param) to get output probability of a state
  * </EN>
  * 
- * $Revision: 1.3 $
+ * $Revision: 1.5 $
  * 
  */
 /*
  * Copyright (c) 1991-2006 Kawahara Lab., Kyoto University
  * Copyright (c) 2000-2005 Shikano Lab., Nara Institute of Science and Technology
- * Copyright (c) 2005-2006 Julius project team, Nagoya Institute of Technology, Nagoya Institute of Technology
+ * Copyright (c) 2005-2006 Julius project team, Nagoya Institute of Technology
  * All rights reserved
  */
 
@@ -64,6 +64,21 @@ outprob_init(HTK_HMM_INFO *hmminfo,
 	     int gprune_method, int gprune_mixnum
 	     )
 {
+  /* check if variances are inversed */
+  if (!hmminfo->variance_inversed) {
+    /* here, inverse all variance values for faster computation */
+    htk_hmm_inverse_variances(hmminfo);
+    hmminfo->variance_inversed = TRUE;
+  }
+  /* check if variances are inversed */
+  if (gshmm) {
+    if (!gshmm->variance_inversed) {
+      /* here, inverse all variance values for faster computation */
+      htk_hmm_inverse_variances(gshmm);
+      gshmm->variance_inversed = TRUE;
+    }
+  }
+
   /** select functions **/
   /* select pruning function to compute likelihood of a mixture component
      and set the pointer to global */
