@@ -11,13 +11,13 @@
  * @brief  Memory allocation of word dictionary information
  * </EN>
  * 
- * $Revision: 1.2 $
+ * $Revision: 1.4 $
  * 
  */
 /*
  * Copyright (c) 1991-2006 Kawahara Lab., Kyoto University
  * Copyright (c) 2000-2005 Shikano Lab., Nara Institute of Science and Technology
- * Copyright (c) 2005-2006 Julius project team, Nagoya Institute of Technology, Nagoya Institute of Technology
+ * Copyright (c) 2005-2006 Julius project team, Nagoya Institute of Technology
  * All rights reserved
  */
 
@@ -36,6 +36,7 @@ word_info_new()
   WORD_INFO *new;
 
   new = (WORD_INFO *)mymalloc(sizeof(WORD_INFO));
+  new->mroot = NULL;
 
   return(new);
 }
@@ -50,11 +51,7 @@ word_info_free(WORD_INFO *winfo)
 {
   WORD_ID w;
   /* free each word info */
-  for(w=0;w<winfo->num;w++) {
-    free(winfo->wname[w]);
-    free(winfo->woutput[w]);
-    free(winfo->wseq[w]);
-  }
+  if (winfo->mroot != NULL) mybfree2(&(winfo->mroot));
   /* free word info */
   free(winfo->wname);
   free(winfo->woutput);
