@@ -18,13 +18,13 @@
  * of audio input, and file I/O for that.
  * </EN>
  * 
- * $Revision: 1.2 $
+ * $Revision: 1.4 $
  * 
  */
 /*
  * Copyright (c) 1991-2006 Kawahara Lab., Kyoto University
  * Copyright (c) 2000-2005 Shikano Lab., Nara Institute of Science and Technology
- * Copyright (c) 2005-2006 Julius project team, Nagoya Institute of Technology, Nagoya Institute of Technology
+ * Copyright (c) 2005-2006 Julius project team, Nagoya Institute of Technology
  * All rights reserved
  */
 
@@ -126,10 +126,10 @@ new_SS_calculate(SP16 *wave, int wavelen, Value para, int *slen)
 #endif
   
   /* allocate work area */
+  spec = (float *)mymalloc((fftN + 1) * sizeof(float));
   bf = (float *)mymalloc((fftN + 1) * sizeof(float));
   Re = (float *)mymalloc((fftN + 1) * sizeof(float));
   Im = (float *)mymalloc((fftN + 1) * sizeof(float));
-  spec = (float *)mymalloc((fftN + 1) * sizeof(float));
   for(i=0;i<fftN;i++) spec[i] = 0.0;
   
   /* Caluculate Sum of Noise Power Spectral */
@@ -145,6 +145,10 @@ new_SS_calculate(SP16 *wave, int wavelen, Value para, int *slen)
     }
     end = i;
 
+    if (para.zmeanframe) {
+      ZMeanFrame(bf, para.framesize);
+    }
+
     /* Pre-emphasis */
     PreEmphasise(bf, para);
     /* Hamming Window */
